import '@aws-cdk/assert/jest'
import { EventBus } from '@aws-cdk/aws-events'

import { Code, Runtime } from '@aws-cdk/aws-lambda'
import { Stack } from '@aws-cdk/core'

import { EventFunction } from '.'

test('Has one Lambda Function', () => {
  const stack = new Stack()
  const mockEventBus = new EventBus(stack, 'mockBus')

  new EventFunction(stack, 'testing', {
    ruleProps: {
      eventBus: mockEventBus,
      eventPattern: { detailType: ['TestType'] },
    },
    functionProps: {
      runtime: Runtime.NODEJS,
      code: Code.fromInline('function handler(event, context){}'),
      handler: 'handler',
      functionName: 'testing-function',
    },
  })

  expect(stack).toHaveResource('AWS::Lambda::Function', {
    Code: { ZipFile: 'function handler(event, context){}' },
    Handler: 'handler',
    Runtime: 'nodejs',
  })
})
