import '@aws-cdk/assert/jest'
import { EventBus } from '@aws-cdk/aws-events'
import { Code, Runtime } from '@aws-cdk/aws-lambda'
import { Stack } from '@aws-cdk/core'

import { EventFunction } from '.'

test('Default configuration of the Processing DLQ with provided name', () => {
  const stack = new Stack()
  const mockEventBus = new EventBus(stack, 'mockBus')

  new EventFunction(stack, 'testing', {
    ruleProps: {
      eventBus: mockEventBus,
      eventPattern: { detailType: ['TestType'] },
    },
    functionProps: {
      runtime: Runtime.NODEJS,
      code: Code.fromInline('function handler(event, context){}'),
      handler: 'handler',
    },
    processingDlqProps: {
      queueName: 'test-processingDlq',
    },
  })

  expect(stack).toHaveResource('AWS::SQS::Queue', {
    QueueName: 'test-processingDlq',
  })
  expect(stack).toHaveResource('AWS::Lambda::Function', {
    Environment: {
      Variables: {
        PROCESSING_DLQ_ARN: {
          'Fn::GetAtt': ['testingtestingprocessingdlq330C4B39', 'Arn'],
        },
        PROCESSING_DLQ_NAME: {
          'Fn::GetAtt': ['testingtestingprocessingdlq330C4B39', 'QueueName'],
        },
      },
    },
  })
})
