import '@aws-cdk/assert/jest'
import { EventBus } from '@aws-cdk/aws-events'
import { Code, Runtime } from '@aws-cdk/aws-lambda'
import { Stack } from '@aws-cdk/core'

import { EventFunction } from '.'

test('Has one Rule with a default name', () => {
  const stack = new Stack()
  const mockEventBus = new EventBus(stack, 'mockBus')

  new EventFunction(stack, 'testing', {
    ruleProps: {
      eventBus: mockEventBus,
      eventPattern: { detailType: ['TestType'] },
    },
    functionProps: {
      runtime: Runtime.NODEJS,
      code: Code.fromInline('function handler(event, context){}'),
      handler: 'handler',
    },
  })

  expect(stack).toHaveResource('AWS::Events::Rule', {
    EventBusName: { Ref: 'mockBus7B31C832' },
    State: 'ENABLED',
    Targets: [
      {
        Arn: {
          'Fn::GetAtt': ['testingtestingfunction2038CA6B', 'Arn'],
        },
        DeadLetterConfig: {
          Arn: {
            'Fn::GetAtt': ['testingtestingdeliverydlqB4CC5086', 'Arn'],
          },
        },
        Id: 'Target0',
      },
    ],
    EventPattern: {
      'detail-type': ['TestType'],
    },
  })
})
